summaryrefslogtreecommitdiffstats
path: root/sys/net/pfil.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/net/pfil.c')
-rw-r--r--sys/net/pfil.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/net/pfil.c b/sys/net/pfil.c
index a53051b..2ed40b2 100644
--- a/sys/net/pfil.c
+++ b/sys/net/pfil.c
@@ -61,7 +61,7 @@ pfil_init(ph)
* PFIL_IN call me on incoming packets
* PFIL_OUT call me on outgoing packets
* PFIL_ALL call me on all of the above
* PFIL_WAITOK OK to call malloc with 0.
*/
int
pfil_add_hook(func, flags, ph)
@@ -97,7 +97,7 @@ pfil_list_add(list, func, flags)
struct packet_filter_hook *pfh;
pfh = (struct packet_filter_hook *)malloc(sizeof(*pfh), M_IFADDR,
- flags & PFIL_WAITOK ? 0 : M_NOWAIT);
+ flags & PFIL_WAITOK ? M_WAITOK : M_NOWAIT);
if (pfh == NULL)
return ENOMEM;
pfh->pfil_func = func;
@@ -61,7 +61,7 @@ pfil_init(ph)
* PFIL_OUT call me on outgoing packets
* PFIL_ALL call me on all of the above
- * PFIL_WAITOK OK to call malloc with 0.
+ * PFIL_WAITOK OK to call malloc with M_WAITOK.
*/
int
OpenPOWER on IntegriCloud